#!/usr/bin/env/python
# -*- coding: utf-8 -*-
#===============================================================================
''' Pretvori IPTV playlisto iz VLC v MediaPortal obliko
 
VLC oblika:
#EXTINF:0,23 - Discovery Channel
udp://@239.1.1.53:5000

MediaPortal:
#EXTINF:0,Discovery Channel
elecard://239.1.1.53:5000:t=m2t/udp

Ker ima MediaPortal možnost priprave skupin in premeščanja programov, 
številke programov niso potrebne in jih zato lahko iz seznama odstranimo.

'''  
#===============================================================================
from optparse import OptionParser
import codecs
import re
import sys

PROGNUM = re.compile(r"INF:0,(\d+ - *)")
PROGINFO = re.compile(r"(udp://@*)(.*)(:5000$)")

def convert(infile, num, outfile = None):
    '''
    Pretvori
    @param infile: ime vhodne datoteke
    @param num: ali naj odstrani številke programov
    @param outfile: ime izhodna datoteke ali stdout
    '''
    #vhod je običajno v Windows obliki
    instream = codecs.open(infile, "Ur", encoding='cp1250')
    
    #izhod
    if outfile == None:
        outstream = sys.stdout
    else:
        outstream = codecs.open(outfile, "w")
        
    for line in instream.readlines():
        if num:
            #številka programa
            result = PROGNUM.sub(r"INF:0,", line)
        else:
            result = line
        #podatki programa
        result = PROGINFO.sub(r"elecard://\2:5000:t=m2t/udp", result)
        outstream.write(result)
    
    if outfile != None: 
        outstream.close()
        
def main():
    '''main'''
    par = OptionParser(usage="%prog vhod [izhod]", 
          description="Pretvori IPTV playlisto iz VLC v MediaPortal obliko")
    par.add_option('-n', '--num', 
                   action ='store_true', 
                   help=u'odstrani številke programov')

    opt, args = par.parse_args()
    if len(args) == 1:
        convert(args[0], opt.num)
    elif len(args) == 2:
        convert(args[0], opt.num, args[1])
    else:
        par.print_help()
    
if __name__ == '__main__':
    main()
